@@ -1,18 +1,21 @@
-// using
+// uses
 use lmaths::*;
 use crate::Shape;
-//
 
+/// The support point between two shape in a certain direction
 #[derive(Clone, Debug, Copy)]
 pub struct SupportPoint {
+    /// Support coordinate
     pub v: Vector2,
-    pub sup_a: Vector2,
-    pub sup_b: Vector2,
+    /// Shape A point
+    sup_a: Vector2,
+    /// Shape B point
+    sup_b: Vector2,
 }
 
 #[allow(dead_code)]
 impl SupportPoint {
-
+    /// Create a new empty Support Point
     pub fn new() -> Self {
         Self {
             v: Vector2::ZERO,
@@ -21,6 +24,7 @@ impl SupportPoint {
         }
     }
 
+    /// Generate the support point between 2 shapes, using the Minkowski difference
     pub fn from_minkowski (left:&dyn Shape, right:&dyn Shape, direction:Vector2) -> Self {
         let l = left.support_point(direction);
         let r = right.support_point(-direction);
