@@ -1,11 +1,8 @@
 mod aabb;
 mod circle;
+mod polygon;
 
 // re-exports
 pub use aabb::AABB;
 pub use circle::Circle;
-
-
-
-
-
+pub use polygon::Polygon;
\ No newline at end of file
